@@ -134,12 +134,13 @@ class RelatedView(BaseView):
         request,
         obj,
         obj_serializer,
+        *,
         extend_conditions: dict = None,
         need_results=False,
         need_queryset=False,
         keys=None,
-        related_obj: list = None,
-        m_to_m_obj: list = None,
+        related_objs: list = None,
+        m_to_m_objs: list = None,
         related_mapping: dict = None,
         m_to_m_mapping: dict = None,
         **kwargs,
@@ -148,24 +149,19 @@ class RelatedView(BaseView):
         扩展返回字段（关联表）
         1、获取queryset
         2、扩展字段
-        :param request:
-        :param obj:
-        :param obj_serializer:
-        :param obj_relevance: 外键关联对象
-        :param mapping: 需要扩展字段对应的映射
-        :return:
+
         """
         data = self.get_req_args(request, extend_conditions)
         results, queryset, current_page_queryset = self.find(obj, data, obj_serializer)
 
         try:
-            if not related_obj:
-                related_obj, related_mapping = self.injection_data.related_data("GET")
-            if not m_to_m_obj:
-                m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data("GET")
+            if not related_objs:
+                related_objs, related_mapping = self.injection_data.related_data("GET")
+            if not m_to_m_objs:
+                m_to_m_objs, m_to_m_mapping = self.injection_data.m_to_m_data("GET")
             if results.data and results.data.result:
                 result = self.relate.extend_result_field(
-                    obj_serializer, related_obj, m_to_m_obj, related_mapping, m_to_m_mapping, current_page_queryset
+                    obj_serializer, related_objs, m_to_m_objs, related_mapping, m_to_m_mapping, current_page_queryset
                 )
                 results.data.result = result
         except Exception as e:
@@ -179,10 +175,12 @@ class RelatedView(BaseView):
         request,
         obj,
         obj_serializer,
+        *,
         data=None,
         need_results=False,
-        related_obj: list = None,
-        m_to_m_obj: list = None,
+        raise_exception=False,
+        related_objs: list = None,
+        m_to_m_objs: list = None,
         related_mapping=None,
         m_to_m_mapping=None,
         **kwargs,
@@ -193,12 +191,12 @@ class RelatedView(BaseView):
         if data.get("data"):
             data = data.get("data")
         serializer = obj_serializer(data=data)
-        if not related_obj:
-            related_obj, related_mapping = self.injection_data.related_data("POST")
-        if not m_to_m_obj:
-            m_to_m_obj, m_to_m_mapping = self.injection_data.m_to_m_data("POST")
-        self.relate.execute_related_extend(related_obj, related_mapping, data)
-        self.relate.execute_m_to_m_extend(m_to_m_obj, m_to_m_mapping, data)
+        if not related_objs:
+            related_objs, related_mapping = self.injection_data.related_data("POST")
+        if not m_to_m_objs:
+            m_to_m_objs, m_to_m_mapping = self.injection_data.m_to_m_data("POST")
+        self.relate.execute_related_extend(related_objs, related_mapping, data)
+        self.relate.execute_m_to_m_extend(m_to_m_objs, m_to_m_mapping, data)
         try:
             valid = serializer.is_valid(raise_exception=True)
             serializer.save()
@@ -206,6 +204,8 @@ class RelatedView(BaseView):
             results.status = SUCCESS
             results.code = 200
         except Exception as e:
+            if raise_exception:
+                raise e
             results.code, results.describe = get_error_status_code(e)
         if need_results:
             return results
@@ -235,6 +235,7 @@ class RelatedView(BaseView):
         extend_conditions: dict = None,
         need_results=False,
         need_queryset=False,
+        raise_exception=False,
         related_obj: list = None,
         m_to_m_obj: list = None,
         related_mapping=None,
@@ -262,5 +263,6 @@ class RelatedView(BaseView):
             extend_conditions=extend_conditions,
             need_results=need_results,
             need_queryset=need_queryset,
+            raise_exception=raise_exception,
             **kwargs,
         )
